==> kreetingkard-0.4.3.tar.gz: kreetingkard/src/kkcmdimage.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Tasuku Suzuki                                   *
 *   tasuku@linux-life.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KKCMDIMAGE_H
#define KKCMDIMAGE_H

#include <qpixmap.h>

#include "kkcmdbase.h"

class KKCmdImage : public KKCmdBase
{
public:
	KKCmdImage( KKDoc* doc );

protected:
	QString propertyName();
	void execute( KKItem* item );
	void unexecute( KKItem* item );
	void begin( KKItem* item );
	bool end( KKItem* item );

private:
	QMap<KKItem*,QPixmap> m_before;
	QMap<KKItem*,QPixmap> m_after;
};

#endif //KKCMDIMAGE_H

==> kreetingkard-0.5.0.tar.gz: kreetingkard/src/kkcmdimage.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Tasuku Suzuki                                   *
 *   tasuku@linux-life.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KKCMDIMAGE_H
#define KKCMDIMAGE_H

#include <qimage.h>

#include "kkcmdbase.h"

class KKCmdImage : public KKCmdBase
{
public:
	KKCmdImage( KKDoc* doc );

protected:
	QString propertyName();
	void execute( KKItem* item );
	void unexecute( KKItem* item );
	void begin( KKItem* item );
	bool end( KKItem* item );

private:
	QMap<KKItem*,QImage> m_before;
	QMap<KKItem*,QImage> m_after;
};

#endif //KKCMDIMAGE_H
